The `android:hasFragileUserData` attribute specifies when the user uninstalls an app, whether or not to show the user a
 prompt to keep the app's data. The default value is "false".
 
This value should be set explicitly in the application to indicate whether the application is handling important user
data or not.
